/* GSequencer - Advanced GTK Sequencer
 * Copyright (C) 2005-2017 Joël Krähemann
 *
 * This file is part of GSequencer.
 *
 * GSequencer is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * GSequencer is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with GSequencer.  If not, see <http://www.gnu.org/licenses/>.
 */

#ifndef __AGS_OUTPUT_LISTING_EDITOR_CALLBACKS_H__
#define __AGS_OUTPUT_LISTING_EDITOR_CALLBACKS_H__

#include <glib.h>
#include <glib-object.h>

#include <gtk/gtk.h>

#include <ags/X/ags_output_listing_editor.h>

#include <ags/X/ags_machine.h>

int ags_output_listing_editor_parent_set_callback(GtkWidget *widget,
						  GtkObject *old_parent,
						  AgsOutputListingEditor *output_listing_editor);

void ags_output_listing_editor_resize_pads_callback(AgsMachine *machine, GType channel_type,
						    guint pads, guint pads_old,
						    AgsOutputListingEditor *output_listing_editor);

#endif /*__AGS_OUTPUT_LISTING_EDITOR_CALLBACKS_H__*/
